summaryrefslogtreecommitdiffstats
path: root/configdialog/kbfxconfigdlglayout.ui.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:30:08 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:30:08 -0600
commitf61f056943a68ecc5fa7e7789a7b9c82901a9157 (patch)
tree799817257250d71692535da8bd6e8aa3b3519b3f /configdialog/kbfxconfigdlglayout.ui.h
parent7e48847d0a084b6ff3a5d0eeb4a3c1b975cda4e5 (diff)
downloadkbfx-f61f056943a68ecc5fa7e7789a7b9c82901a9157.tar.gz
kbfx-f61f056943a68ecc5fa7e7789a7b9c82901a9157.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'configdialog/kbfxconfigdlglayout.ui.h')
-rw-r--r--configdialog/kbfxconfigdlglayout.ui.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/configdialog/kbfxconfigdlglayout.ui.h b/configdialog/kbfxconfigdlglayout.ui.h
index d57e9e0..b8a4d55 100644
--- a/configdialog/kbfxconfigdlglayout.ui.h
+++ b/configdialog/kbfxconfigdlglayout.ui.h
@@ -187,7 +187,7 @@ void KbfxConfigDlgLayout::KbfxLayoutProperty_activated( int index )
break;
}
default: /* default action switch does nothing */
- kdDebug() << "Default action switch for saving tqlayout changed..." << endl;
+ kdDebug() << "Default action switch for saving layout changed..." << endl;
}
KbfxShowAll ();
@@ -426,7 +426,7 @@ void KbfxConfigDlgLayout::KbfxLayoutProperty_activated( int index )
break;
}
default: /* default action switch should never be reached */
- kdDebug() << "Default action switch for tqlayout changed..." << endl;
+ kdDebug() << "Default action switch for layout changed..." << endl;
}
}
@@ -465,7 +465,7 @@ void KbfxConfigDlgLayout::KbfxExportFileAction()
<< KbfxExportLayoutRcDialogURL
<< endl;
/* write tqlayout theme configuration file */
KConfig *layoutconfig = new KConfig ( KbfxExportLayoutRcDialogURL );
layoutconfig->setGroup ( "KbfxButton" );
@@ -465,7 +465,7 @@ void KbfxConfigDlgLayout::KbfxExportFileAction()
<< KbfxExportLayoutRcDialogURL
<< endl;
- /* write tqlayout theme configuration file */
+ /* write layout theme configuration file */
KConfig *layoutconfig = new KConfig ( KbfxExportLayoutRcDialogURL );
layoutconfig->setGroup ( "KbfxButton" );